<?php
if ( ! defined( 'MYCRED_LISFTERLMS_VERSION' ) ) exit;

/**
 * The class_exists() check is recommended, to prevent problems during upgrade
 * or when the Groups component is disabled
 */
if ( ! class_exists( 'myCRED_LifterLMS_Section' ) ) :
	class myCRED_LifterLMS_Section extends myCRED_Hook {
		
		/**
		 * Construct
		 */
		function __construct( $hook_prefs, $type = MYCRED_DEFAULT_TYPE_KEY ) {

			parent::__construct( array(
				'id'       => 'mycred_lifterlms_section',
				'defaults' => array(
					'creds'  => 1,
					'log'    => '%plural% for completing a section',
					'limit'  => '0/x'
				)
			), $hook_prefs, $type );
		}

		/**
		 * Hook into WordPress
		 */
		public function run() {
			
			if ( $this->prefs['creds'] !== 0 ) {
				add_action( 'lifterlms_section_completed', array( $this, 'section_completed' ), 100, 2 );
			}
		}

		/**
		 * Runs when a student completes a section
		 *
		 * @since 1.0
		 *
		 * @param $student_id
		 * @param $section_id
		 */
		public function section_completed( $student_id, $section_id ) {
			// Check for exclusion
			if ( $this->core->exclude_user( $student_id ) ) return;

			$refrence = 'lifterlms_section_completed';

			$data = [ 'section' => $section_id ];

			// Enforce limit and make sure users only get points once per unique section
			if ( ! $this->over_hook_limit( '', $refrence, $student_id ) && ! $this->core->has_entry( $refrence, $student_id, $section_id, $data, $this->mycred_type ) ) {
				$this->core->add_creds(
					$refrence,
					$student_id,
					$this->prefs['creds'],
					$this->prefs['log'],
					$section_id,
					$data
				);
			}
		}

		/**
		* Add Settings
		*/
		public function preferences() {
			// Our settings are available under $this->prefs
			$prefs = $this->prefs; ?>

			<div class="hook-instance">
				<div class="row">
					<div class="col-lg-2 col-md-6 col-sm-6 col-xs-12">
						<div class="form-group">
							<label for="<?php echo $this->field_id( 'creds' ); ?>"><?php echo $this->core->plural(); ?></label>
							<input type="text" name="<?php echo $this->field_name( 'creds' ); ?>" id="<?php echo $this->field_id( 'creds' ); ?>" value="<?php echo $this->core->number( $prefs['creds'] ); ?>" class="form-control" />
						</div>
					</div>
					<div class="col-lg-4 col-md-6 col-sm-6 col-xs-12">
						<div class="form-group">
							<label for="<?php echo $this->field_id( 'limit' ); ?>"><?php _e( 'Limit', 'mycred' ); ?></label>
							<?php echo $this->hook_limit_setting( $this->field_name( 'limit' ), $this->field_id( 'limit' ), $prefs['limit'] ); ?>
						</div>
					</div>
					<div class="col-lg-6 col-md-12 col-sm-12 col-xs-12">
						<div class="form-group">
							<label for="<?php echo $this->field_id( 'log' ); ?>"><?php _e( 'Log Template', 'mycred' ); ?></label>
							<input type="text" name="<?php echo $this->field_name( 'log' ); ?>" id="<?php echo $this->field_id( 'log' ); ?>" placeholder="<?php _e( 'required', 'mycred' ); ?>" value="<?php echo esc_attr( $prefs['log'] ); ?>" class="form-control" />
							<span class="description"><?php echo $this->available_template_tags( array( 'general' ) ); ?></span>
						</div>
					</div>
				</div>
			</div>
			<?php
		}

		/**
		 * Sanitize Preferences
		 */
		public function sanitise_preferences( $data ) {

			if ( isset( $data['limit'] ) && isset( $data['limit_by'] ) ) {
				$limit = sanitize_text_field( $data['limit'] );
				if ( $limit == '' ) $limit = 0;
				$data['limit'] = $limit . '/' . $data['limit_by'];
				unset( $data['limit_by'] );
			}

			return $data;

		}

	}
endif;

?>