<?php
/**
 * Plugin Name: myCRED - LifterLMS Integration
 * Description: Extend the power of the LifterLMS plugin with the popular myCRED points management plugin.
 * Version: 1.1
 * Author: myCRED
 * Author URI: www.mycred.me
 * Requires at least: WP 4.8
 * Tested up to: WP 5.7.1
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if ( ! class_exists( 'myCRED_LifterLMS' ) ) :
	final class myCRED_LifterLMS {

		// Plugin Version
		public $version             = '1.1';

		// Instnace
		protected static $_instance = NULL;

		/**
		 * Setup Instance
		 * @since 1.1.2
		 * @version 1.0
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Not allowed
		 * @since 1.1.2
		 * @version 1.0
		 */
		public function __clone() { _doing_it_wrong( __FUNCTION__, 'Cheatin&#8217; huh?', '1.1.2' ); }

		/**
		 * Not allowed
		 * @since 1.1.2
		 * @version 1.0
		 */
		public function __wakeup() { _doing_it_wrong( __FUNCTION__, 'Cheatin&#8217; huh?', '1.1.2' ); }

		/**
		 * Define
		 * @since 1.1.2
		 * @version 1.0
		 */
		private function define( $name, $value, $definable = true ) {
			if ( ! defined( $name ) )
				define( $name, $value );
			elseif ( ! $definable && defined( $name ) )
				_doing_it_wrong( 'myCRED_LifterLMS->define()', 'Could not define: ' . $name . ' as it is already defined somewhere else!', '1.1.2' );
		}

		/**
		 * Require File
		 * @since 1.1.2
		 * @version 1.0
		 */
		public function file( $required_file ) {
			if ( file_exists( $required_file ) )
				require_once $required_file;
			else
				_doing_it_wrong( 'myCRED_LifterLMS->file()', 'Requested file ' . $required_file . ' not found.', '1.1.2' );
		}

		/**
		 * Construct
		 * @since 1.0
		 * @version 1.0
		 */
		public function __construct() {

			$this->define_constants();

			if( ! function_exists('is_plugin_active') )
				include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

			$is_lifterlms_active = is_plugin_active( 'lifterlms/lifterlms.php' );
			$is_mycred_active    = is_plugin_active( 'mycred/mycred.php' );

			if ( $is_lifterlms_active && $is_mycred_active ) {

				$this->includes();
				
				add_filter( 'mycred_setup_hooks',    array( $this, 'register_hooks' ) );
				// Setup References corresponding to this plugin
				add_filter( 'mycred_all_references', array( $this, 'setup_references' ) );
			}
			
			if ( ! $is_mycred_active ) {
				add_action( 'admin_notices', array( $this, 'mycred_inactive_admin_notice' ) );
			}

		}

		/**
		 * Define Constants
		 * @since 1.0
		 * @version 1.0
		 */
		private function define_constants() {

			$this->define( 'MYCRED_LISFTERLMS_VERSION',       $this->version );
			$this->define( 'MYCRED_LISFTERLMS_SLUG',          'mycred-lifterlms' );

			$this->define( 'MYCRED_LISFTERLMS',               __FILE__ );
			$this->define( 'MYCRED_LISFTERLMS_ROOT',          plugin_dir_path( MYCRED_LISFTERLMS ) );
			$this->define( 'MYCRED_LISFTERLMS_INC_DIR',       MYCRED_LISFTERLMS_ROOT . 'includes/' );

		}

		/**
		 * Include Plugin Files
		 * @since 1.0
		 * @version 1.0
		 */
		public function includes() {

			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-course.php' );
			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-quiz.php' );
			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-lesson.php' );
			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-section.php' );
			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-membership.php' );
			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-plan.php' );
			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-achievement.php' );
			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-certificate.php' );
			$this->file( MYCRED_LISFTERLMS_INC_DIR . 'mycred-lifterlms-endpoint.php' );

		}

		public function register_hooks( $installed )
		{
			$installed['mycred_lifterlms_course'] = array(
				'title'       => __( 'LifterLMS: Courses', 'mycred-lifterlms' ),
				'description' => __( 'Hook description', 'mycred-lifterlms' ),
				'callback'    => array( 'myCRED_LifterLMS_Course' )
			);
			$installed['mycred_lifterlms_quiz'] = array(
				'title'       => __( 'LifterLMS: Quizes', 'mycred-lifterlms' ),
				'description' => __( 'Hook description', 'mycred-lifterlms' ),
				'callback'    => array( 'myCRED_LifterLMS_Quiz' )
			);
			$installed['mycred_lifterlms_lesson'] = array(
				'title'       => __( 'LifterLMS: Lessons', 'mycred-lifterlms' ),
				'description' => __( 'Hook description', 'mycred-lifterlms' ),
				'callback'    => array( 'myCRED_LifterLMS_Lesson' )
			);
			$installed['mycred_lifterlms_section'] = array(
				'title'       => __( 'LifterLMS: Sections', 'mycred-lifterlms' ),
				'description' => __( 'Hook description', 'mycred-lifterlms' ),
				'callback'    => array( 'myCRED_LifterLMS_Section' )
			);
			$installed['mycred_lifterlms_membership'] = array(
				'title'       => __( 'LifterLMS: Memberships', 'mycred-lifterlms' ),
				'description' => __( 'Hook description', 'mycred-lifterlms' ),
				'callback'    => array( 'myCRED_LifterLMS_Membership' )
			);
			$installed['mycred_lifterlms_plan'] = array(
				'title'       => __( 'LifterLMS: Plans / Products', 'mycred-lifterlms' ),
				'description' => __( 'Hook description', 'mycred-lifterlms' ),
				'callback'    => array( 'myCRED_LifterLMS_Plan' )
			);
			$installed['mycred_lifterlms_achievement'] = array(
				'title'       => __( 'LifterLMS: Achievements', 'mycred-lifterlms' ),
				'description' => __( 'Hook description', 'mycred-lifterlms' ),
				'callback'    => array( 'myCRED_LifterLMS_Achievement' )
			);
			$installed['mycred_lifterlms_certificate'] = array(
				'title'       => __( 'LifterLMS: Certificates', 'mycred-lifterlms' ),
				'description' => __( 'Hook description', 'mycred-lifterlms' ),
				'callback'    => array( 'myCRED_LifterLMS_Certificate' )
			);
			return $installed;
		}

		/**
		 * Setup references so they show on the Edit Points log screen
		 *
		 * @param $references
		 *
		 * @return mixed
		 */
		function setup_references( $references ) {

			$references['lifterlms_course_completed'] 			= 'LifterLMS: Student completes a course';
			$references['lifterlms_lesson_completed'] 			= 'LifterLMS: Student completes a lesson';
			$references['lifterlms_section_completed'] 			= 'LifterLMS: Student completes a section';
			$references['lifterlms_course_track_completed'] 	= 'LifterLMS: Student comepletes a course track';
			$references['lifterlms_quiz_passed'] 				= 'LifterLMS: Student passes a quiz';
			$references['lifterlms_quiz_failed'] 				= 'LifterLMS: Student fails a quiz';
			$references['lifterlms_quiz_completed'] 			= 'LifterLMS: Student completes a quiz';
			$references['llms_user_enrolled_in_course'] 		= 'LifterLMS: Student enrolls in a course';
			$references['llms_user_added_to_membership_level'] 	= 'LifterLMS: Student is added to a membership level';
			$references['lifterlms_access_plan_purchased'] 		= 'LifterLMS: Student Purchases an Access Plan or Product';
			$references['llms_user_earned_achievement'] 		= 'LifterLMS: Student earns a new achievement';
			$references['llms_user_earned_certificate'] 		= 'LifterLMS: Student earns a new certificate';

			return $references;

		}

		/**
		 * Add an admin notice when the myCRED plugin is not currently active
		 * @since 1.0
		 * @version 1.0
		 */
		public function mycred_inactive_admin_notice() {
			$class   = 'notice notice-error';
			$message = __( 'myCRED is currently not active. Please activate it so that you can continue to use this LifterLMS extension.', 'mycred-lifterlms' );
			printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) );
		}

	}
endif;

function mycred_lifterlms_plugin() {
	return myCRED_LifterLMS::instance();
}
add_action( 'plugins_loaded', 'mycred_lifterlms_plugin' );